generate_test_project.py
========================

`View code on Github <https://github.com/activist-org/ts-backend-check/blob/main/src/ts_backend_check/cli/generate_test_project.py>`_

.. automodule:: ts_backend_check.cli.generate_test_project
    :members:
    :private-members:
